/**
 *  Copyright (c) 2015,
 *  BTC Embedded Systems AG, Oldenburg, Germany
 *  All rights reserved
 *  ---------------------------------------------------------
 *  $Author: $
 *  $Date:  $
 *  $Revision: $
 **/

package com.btc.ep.base.bl.impl;

import com.btc.ep.base.bl.Vector;

/**
 * This class implements the VectorImpl
 */
public class VectorElementCollectionImpl extends ModelElementImpl {

    private Vector vector;
    private long vectorElementCollectionRef;
    private long startStep;
    private long endStep;

    /**
     * JPA Entity Default constructor
     * <p>The default constructor must be a public or protected zero-argument constructor.</p>
     */
    protected VectorElementCollectionImpl() {
    }

    /**
     * Constructor
     *
     * @param vector - the 'parent' Vector
     * @param vectorElementCollectionRef - int (the own RefID)
     * @param startStep - int
     * @param endStep - int
     */
    public VectorElementCollectionImpl(Vector vector, long vectorElementCollectionRef, long startStep, long endStep) {
        this.vector = vector;
        this.setStartStep(startStep);
        this.setEndStep(endStep);
        this.vectorElementCollectionRef = vectorElementCollectionRef;
    }

    /**
     * GetVectorElementCollectionRef
     *
     * @return vectorElementCollectionRef - int
     */
    public long getVectorElementCollectionRef() {
        return vectorElementCollectionRef;
    }

    /**
     * Get startStep.
     * 
     * @return the startStep
     */
    public long getStartStep() {
        return startStep;
    }

    /**
     * Get endStep.
     * 
     * @return the endStep
     */
    public long getEndStep() {
        return endStep;
    }

    /**
     * Increment start and end Step by offset
     *
     * @param increment - the value to increment the start and end Step
     */
    public void incrementSteps(long increment) {
        startStep = startStep + increment;
        endStep = endStep + increment;
    }

    /**
     * Decrement start and end Step by offset
     *
     * @param decrement - the value to decrement the start and end Step
     */
    public void decrementSteps(long decrement) {
        if (startStep > decrement) {
            startStep = startStep - decrement;
        } else {
            startStep = 0;
        }

        if (endStep > decrement) {
            endStep = endStep - decrement;
        } else {
            endStep = 0;
        }
    }

    /**
     * Return the size of VectorElements they referenced to this VectorElementCollection
     *
     * @return difference between endStep and startStep +1;
     */
    public long getElementCount() {
        return endStep - startStep + 1;
    }

    /**
     * Increment the size of the VectorElements by offset
     *
     * @param increment - the value to decrement the size of the VectorElements
     */
    public void incrementSize(long increment) {
        endStep = endStep + increment;
    }

    /**
     * Decrement the size of the VectorElements by offset
     *
     * @param decrement - the value to decrement the size of the VectorElements
     */
    public void decrementSize(long decrement) {
        if (endStep - startStep > decrement) {
            endStep = endStep - decrement;
        } else {
            endStep = startStep - 1;
        }
    }

    /**
     * Set startStep.
     * 
     * @param startStep the startStep to set
     */
    public void setStartStep(long startStep) {
        this.startStep = startStep;
    }

    /**
     * Set endStep.
     * 
     * @param endStep the endStep to set
     */
    public void setEndStep(long endStep) {
        this.endStep = endStep;
    }

}
