/**
 *  Copyright (c) 2015,
 *  BTC Embedded Systems AG, Oldenburg, Germany
 *  All rights reserved
 *  ---------------------------------------------------------
 *  $Author: $
 *  $Date:  $
 *  $Revision: $
 **/

package com.btc.ep.base.bl.repository;

import java.util.List;

import com.btc.ep.base.bl.Vector;
import com.btc.ep.base.bl.VectorElement;

/**
 * This interface is used to encapsulate the access to Vectors.
 */
public interface VectorRepository {

    /**
     * Find (load) a existing vector.
     * 
     * @param uid Id of the Vector
     * @return vector
     */
    public Vector findVector(String uid);

    /**
     * Retrieves a list of all stored vectors.
     * 
     * @return list of stored vectors.
     */
    public List<Vector> findAllVectors();

    /**
     * Retrieves a list of all stored vectors.
     * 
     * @param vector - Vector to persist
     * @return attached Vectors.
     */
    public Vector persistVector(Vector vector);

    /**
     * Remove a vector. And all VectorElements
     * 
     * @param vector - Vector to remove
     */
    public void removeVector(Vector vector);

    /*
     * VectorElement(s)
     */

    /**
     * Find (load) a existing vectorElement.
     * 
     * @param uid Id of the VectorElement
     * @return vector
     */
    public VectorElement findVectorElement(String uid);

    /**
     * Find (load) a existing vectorElement.
     * 
     * @param uid Id of the VectorElement
     * @return vector
     */
    public VectorElement findVectorElement(Vector vector, long step);

    /**
     * Find vectorElements of a Vector
     * 
     * @param vector Vector
     * @return list of VectorElements.
     */
    public List<VectorElement> findVectorElements(Vector vector);

    /**
     * Find vectorElements of a Vector ()
     *
     * @param vector Vector
     * @param startStep
     * @param endStep
     * @return list of VectorElements.
     */
    public List<VectorElement> findVectorElements(Vector vector, long startStep, long endStep);

    VectorElement addVectorElement(Vector vector, VectorElement step);

    List<VectorElement> addVectorElements(Vector vector, List<VectorElement> step);

    public void removeVectorElement(Vector vector, long step);
    void removeVectorElement(Vector vector, VectorElement step);
    public void removeVectorElements(Vector vector, long startStep, long endstep);

    /*
     * Only for Test's
     */
    void incrAll();


}
