/**
 *  Copyright (c) 2014, 
 *  BTC Embedded Systems AG, Oldenburg, Germany  
 *  All rights reserved
 *  --------------------------------------------------------- 
 *  $Author: $
 *  $Date:  $
 *  $Revision: $
 **/

package com.btc.ep.base.dal.tests.it.base;

import java.util.concurrent.atomic.AtomicInteger;

import com.btc.ep.base.bl.repository.StandardRepository;
import com.btc.ep.base.transactions.TransactionManager;
import com.btc.ep.core.Services;

/**
 * This class is the base of the unit test.
 * And offers complicated methods to create DTO objects in DAL tests.
 * 
 * @author Martin Manthey
 */
public class BaseTest {


	public final static String jointPointId = "jointPointId";

    protected long startTime;

    protected AtomicInteger counter = new AtomicInteger(1);

    /**
     * deletes all entities in the database
     */
    protected static void deleteDatabase() {
        
        TransactionManager tm = Services.get(TransactionManager.class);
        tm.init(jointPointId, false);
    	
        StandardRepository standardRepository = Services.get(StandardRepository.class);
        standardRepository.clearDatabase(); // delete whole database
        
        tm.commit(jointPointId);
        tm.close(jointPointId);
    }


    /**
     * converts bytes in mb
     * 
     * @param value bytes
     * @return value in mb
     */
    private String convertMemory(long value) {
        return "" + value / 1024 / 1000 + "MB";
    }

    /**
     * prints memory info to the console
     */
    public void memoryInfo() {

        long max = Runtime.getRuntime().maxMemory();
        long free = Runtime.getRuntime().freeMemory();
        long total = Runtime.getRuntime().totalMemory();

        System.out.println("max: " + convertMemory(max));
        System.out.println("free: " + convertMemory(free));
        System.out.println("total: " + convertMemory(total));
        System.out.println("used: " + convertMemory((total - free)));
        System.out.println("");
    }

    /**
     * remarks the time at now
     */
    public void remarkTime() {
        startTime = System.currentTimeMillis();
    }

    /**
     * Call this after call remarkTime().
     * Prints the used time until now to the console.
     *
     * @param usecase description of used time
     * @see BaseTest#remarkTime()
     */
    public void printTime(String usecase) {
        System.out.println(usecase + " time: " + (System.currentTimeMillis() - startTime));
    }

}
