/**
 *  @file      TransactionContext.java
 *  @author    Stefan Reichert
 *
 *  Copyright (c)
 *  BTC Embedded Systems AG
 *  Oldenburg, Germany
 *
 *  --------------------------------
 *  $$Author: ${user} $$
 *  $$Date: ${date} ${time} $$
 *  $$Rev: revision number $$
 *  --------------------------------
 */
package com.btc.ep.base.transactions;

import javax.persistence.EntityManager;


// ---------------------------------------------------------------------------
// Implementation
// ---------------------------------------------------------------------------

/**
 * The TransactionContext class provides access to objects attached to the current transaction (if one exists). The
 * transactional objects are bound to the executing thread. The implementation of this interfaces provides the correct
 * context objects for the current thread.<br>
 * A transaction is available, if the current thread is attached to a unit of work. A unit of work is defined by a
 * method that is annotated with {@link Transactional}.
 * 
 * @see Transactional
 * @see NotTransactional
 * 
 */
public interface TransactionContext {

    /**
     * Returns the currently valid EntityManager.
     * 
     * @return the EntityManager instance to be used for data access
     * 
     * @throws TransactionException in case there is no active transaction
     */
    EntityManager getEntityManager() throws TransactionException;

}

// ---------------------------------------------------------------------------
// END OF FILE
// ---------------------------------------------------------------------------
