/**
 * 
 */
package com.btc.ep.core;

import java.util.HashMap;
import java.util.Map;

import org.osgi.util.tracker.ServiceTracker;

import com.btc.ep.core.impl.Activator;

/**
 * Access globally available Services
 * 
 * @author jacek
 *
 */
@SuppressWarnings({ "rawtypes", "unchecked" })
public class Services {
	
	/**
	 * stores tracker
	 */
	private static Map<String, ServiceTracker> trackers = new HashMap<>();

	/**
	 * stores overriden services
	 */
	private static Map<Class, Object> testServices = new HashMap<>();

	/**
	 * get service tracker; tracker will be cached for further use 
	 *
	 * @param serviceClass the service class
	 * @return service tracker
	 */
	private static ServiceTracker getServiceTracker(Class serviceClass) {
		
		String clazz = serviceClass.getName();
		
		ServiceTracker st = trackers.get(clazz); 
		if (st == null) {
			st = new ServiceTracker(Activator.getContext(), clazz, null);
			st.open();
			trackers.put(clazz, st);
		}
		
		return st;
	}
	
	/**
	 * gets a service of given class.
	 * <p>hosts shouldn't cache the returned service for longer period of time. -> OSGI anti pattern
	 * @param serviceClass 
	 * @return
	 */
	public static <T> T get(Class<T> serviceClass) {
		Object service = testServices.get(serviceClass);
		if (service == null) {
			service = getServiceTracker(serviceClass).getService();
		}
		return (T)service;
	}

	
	/**
	 * Add a service to local service registry. 
	 * <p>This method is primarily for replacing services with test-stubs and not for registering services.
	 * @param serviceClass
	 * @param serviceImplementation
	 */
	public static void addOverride(Class serviceClass, Object serviceImplementation) {
		testServices.put(serviceClass, serviceImplementation);
    }

    /**
     * Clear all service stubs
     */
    public static void clearOverrides() {
    	testServices.clear();
    } 
}
